"""
    Registry User Dashboard constants
"""
# Templates
DASHBOARD_HOME_TEMPLATE = "core_dashboard_registry_app/home.html"
DASHBOARD_FORMS_TEMPLATE_TABLE = (
    "core_dashboard_registry_app/list/my_dashboard_my_forms_table.html"
)
DASHBOARD_FORMS_TEMPLATE_TABLE_PAGINATION = (
    "core_dashboard_registry_app/list/my_dashboard_my_forms_table_pagination.html"
)
# JS
JS_PUBLISH_RESOURCE = "core_dashboard_registry_app/user/js/list/publish.js"
JS_RECORD_REGISTRY = "core_dashboard_registry_app/user/js/record_registry.js"

# CSS
CSS_SELECTION = "core_main_registry_app/user/css/resource_banner/selection.css"

# PATH
PATH_ROLE = "dict_content.Resource.role.@xsi:type"
