{% load staticfiles %}

{% block title %}
	<h1>Dashboard Home</h1>
{% endblock %}

{% block content%}
<div id="menu" class="row center-block good">
	<div class="col-sm-4 text-center">
		<a href="{% url 'core_dashboard_profile' %}">
			<i class="fa fa-user fa-5x" aria-hidden="true" style="color: #EBB057;"></i>
		<br>
		My Profile
		</a>
	</div>
	<div class="col-sm-4 text-center">
		<a href="{% url 'core_dashboard_records' %}">
			<i class="fa fa-globe fa-5x" aria-hidden="true" style="color: #557EB9"></i>
		<br>
		My Resources
		</a>
	</div>
	<div class="col-sm-4 text-center">
	  <a href="{% url 'core_dashboard_workspaces' %}">
			<i class="fa fa-list-ul fa-5x" aria-hidden="true" style="color: #FF5E00;"></i>
		<br>
		My Workspaces
		</a>
	</div>
</div>
{% endblock %}